@@ -32,27 +32,30 @@ pub mod websocket;
 
 use std::{convert::Infallible, fmt::Debug};
 
-pub use addr::{LocalAddr, RemoteAddr};
 use bytes::Bytes;
-#[cfg(feature = "compression")]
-pub use compress::{Compress, CompressionAlgo};
-#[cfg(feature = "csrf")]
-pub use csrf::{CsrfToken, CsrfVerifier};
-pub use data::Data;
-pub use form::Form;
-pub use json::Json;
-#[cfg(feature = "multipart")]
-pub use multipart::{Field, Multipart};
-pub use path::Path;
-pub(crate) use path::PathDeserializer;
-pub use query::Query;
-pub use redirect::Redirect;
-#[cfg(feature = "static-files")]
-pub use static_file::{StaticFileRequest, StaticFileResponse};
-pub use typed_header::TypedHeader;
+use http::header;
 
+#[cfg(feature = "compression")]
+pub use self::compress::{Compress, CompressionAlgo};
+#[cfg(feature = "csrf")]
+pub use self::csrf::{CsrfToken, CsrfVerifier};
+#[cfg(feature = "multipart")]
+pub use self::multipart::{Field, Multipart};
+pub(crate) use self::path::PathDeserializer;
+#[cfg(feature = "static-files")]
+pub use self::static_file::{StaticFileRequest, StaticFileResponse};
 #[cfg(feature = "tempfile")]
 pub use self::tempfile::TempFile;
+pub use self::{
+    addr::{LocalAddr, RemoteAddr},
+    data::Data,
+    form::Form,
+    json::Json,
+    path::Path,
+    query::Query,
+    redirect::Redirect,
+    typed_header::TypedHeader,
+};
 use crate::{
     body::Body,
     error::{ReadBodyError, Result},
@@ -459,6 +462,29 @@ pub trait IntoResponse: Send {
         }
     }
 
+    /// Wrap an `impl IntoResponse` to with a new content type.
+    ///
+    /// # Example
+    ///
+    /// ```
+    /// use poem::{http::HeaderValue, IntoResponse};
+    ///
+    /// # tokio::runtime::Runtime::new().unwrap().block_on(async {
+    /// let resp = "hello".with_content_type("text/abc").into_response();
+    /// assert_eq!(resp.content_type(), Some("text/abc"));
+    /// # });
+    /// ```
+    fn with_content_type<V>(self, content_type: V) -> WithContentType<Self>
+    where
+        V: TryInto<HeaderValue>,
+        Self: Sized,
+    {
+        WithContentType {
+            inner: self,
+            content_type: content_type.try_into().ok(),
+        }
+    }
+
     /// Wrap an `impl IntoResponse` to set a status code.
     ///
     /// # Example
@@ -529,6 +555,23 @@ impl<T: IntoResponse> IntoResponse for WithHeader<T> {
     }
 }
 
+/// Returned by [`with_content_type`](IntoResponse::with_content_type) method.
+pub struct WithContentType<T> {
+    inner: T,
+    content_type: Option<HeaderValue>,
+}
+
+impl<T: IntoResponse> IntoResponse for WithContentType<T> {
+    fn into_response(self) -> Response {
+        let mut resp = self.inner.into_response();
+        if let Some(content_type) = self.content_type {
+            resp.headers_mut()
+                .insert(header::CONTENT_TYPE, content_type);
+        }
+        resp
+    }
+}
+
 /// Returned by [`with_header`](IntoResponse::with_status) method.
 pub struct WithStatus<T> {
     inner: T,
